import time
from typing import Optional
import httpx

from linkpreview.exceptions import (
    InvalidContentError,
    InvalidMimeTypeError,
    MaximumContentSizeError,
)


class LinkGrabber:
    headers = {
        "user-agent": (
            "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:95.0) Gecko/20100101 Firefox/95.0"
        ),
        "accept-language": "en-US,en;q=0.5",
        "accept": ("text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8"),
    }

    def __init__(
        self,
        initial_timeout: int = 20,
        maxsize: int = 1048576,
        receive_timeout: int = 10,
        chunk_size: int = 1024,
    ):
        """
        :param initial_timeout in seconds
        :param maxsize in bytes (default 1048576 = 1 MB)
        :param receive_timeout in seconds
        :param chunk_size in bytes
        """
        self.initial_timeout = initial_timeout
        self.maxsize = maxsize
        self.receive_timeout = receive_timeout
        self.chunk_size = chunk_size

    async def get_content(self, url: str, headers: Optional[dict] = None):
        async with httpx.AsyncClient() as client:
            async with client.stream(
                "GET",
                url,
                timeout=self.initial_timeout,
                headers={**self.headers, **headers} if headers else self.headers,
            ) as r:
                r.raise_for_status()

                content_type = r.headers.get("content-type")
                if not content_type:
                    raise InvalidContentError("Invalid content type")

                mime_type = content_type.split(";")[0].lower()
                if mime_type != "text/html":
                    raise InvalidMimeTypeError("Invalid mime type")

                length = r.headers.get("Content-Length")
                if length and int(length) > self.maxsize:
                    raise MaximumContentSizeError("response too large")

                size = 0
                start = time.time()
                content = b""
                async for chunk in r.aiter_bytes(self.chunk_size):
                    if time.time() - start > self.receive_timeout:
                        raise TimeoutError("timeout reached")

                    size += len(chunk)
                    if size > self.maxsize:
                        raise MaximumContentSizeError("response too large")

                    content += chunk

                return content.decode(), url



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waUserPassword/WAProtobufsUserPassword.proto
# Protobuf Python Version: 5.28.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    2,
    '',
    'waUserPassword/WAProtobufsUserPassword.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,waUserPassword/WAProtobufsUserPassword.proto\x12\x17WAProtobufsUserPassword\"\x9b\x04\n\x0cUserPassword\x12@\n\x08\x65ncoding\x18\x01 \x01(\x0e\x32..WAProtobufsUserPassword.UserPassword.Encoding\x12\x46\n\x0btransformer\x18\x02 \x01(\x0e\x32\x31.WAProtobufsUserPassword.UserPassword.Transformer\x12L\n\x0etransformerArg\x18\x03 \x03(\x0b\x32\x34.WAProtobufsUserPassword.UserPassword.TransformerArg\x12\x17\n\x0ftransformedData\x18\x04 \x01(\x0c\x1a\xa9\x01\n\x0eTransformerArg\x12\x0b\n\x03key\x18\x01 \x01(\t\x12I\n\x05value\x18\x02 \x01(\x0b\x32:.WAProtobufsUserPassword.UserPassword.TransformerArg.Value\x1a?\n\x05Value\x12\x10\n\x06\x61sBlob\x18\x01 \x01(\x0cH\x00\x12\x1b\n\x11\x61sUnsignedInteger\x18\x02 \x01(\rH\x00\x42\x07\n\x05value\"G\n\x0bTransformer\x12\x08\n\x04NONE\x10\x00\x12\x16\n\x12PBKDF2_HMAC_SHA512\x10\x01\x12\x16\n\x12PBKDF2_HMAC_SHA384\x10\x02\"%\n\x08\x45ncoding\x12\x08\n\x04UTF8\x10\x00\x12\x0f\n\x0bUTF8_BROKEN\x10\x01\x42*Z(go.mau.fi/whatsmeow/proto/waUserPassword')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waUserPassword.WAProtobufsUserPassword_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z(go.mau.fi/whatsmeow/proto/waUserPassword'
  _globals['_USERPASSWORD']._serialized_start=74
  _globals['_USERPASSWORD']._serialized_end=613
  _globals['_USERPASSWORD_TRANSFORMERARG']._serialized_start=332
  _globals['_USERPASSWORD_TRANSFORMERARG']._serialized_end=501
  _globals['_USERPASSWORD_TRANSFORMERARG_VALUE']._serialized_start=438
  _globals['_USERPASSWORD_TRANSFORMERARG_VALUE']._serialized_end=501
  _globals['_USERPASSWORD_TRANSFORMER']._serialized_start=503
  _globals['_USERPASSWORD_TRANSFORMER']._serialized_end=574
  _globals['_USERPASSWORD_ENCODING']._serialized_start=576
  _globals['_USERPASSWORD_ENCODING']._serialized_end=613
# @@protoc_insertion_point(module_scope)



from __future__ import annotations
import logging

from neonize.exc import UnsupportedEvent
import ctypes
import segno
from typing import TypeVar, Type, Callable, TYPE_CHECKING, Dict
from google.protobuf.message import Message
from threading import Event as EventThread
from .proto.Neonize_pb2 import (
    QR as QREv,
    PairStatus as PairStatusEv,
    Connected as ConnectedEv,
    KeepAliveTimeout as KeepAliveTimeoutEv,
    KeepAliveRestored as KeepAliveRestoredEv,
    LoggedOut as LoggedOutEv,
    StreamReplaced as StreamReplacedEv,
    TemporaryBan as TemporaryBanEv,
    ConnectFailure as ConnectFailureEv,
    ClientOutdated as ClientOutdatedEv,
    StreamError as StreamErrorEv,
    Disconnected as DisconnectedEv,
    HistorySync as HistorySyncEv,
    NewsLetterMessageMeta as NewsLetterMessageMetaEv,
    Message as MessageEv,
    Receipt as ReceiptEv,
    ChatPresence as ChatPresenceEv,
    Presence as PresenceEv,
    JoinedGroup as JoinedGroupEv,
    GroupInfoEvent as GroupInfoEv,
    Picture as PictureEv,
    IdentityChange as IdentityChangeEv,
    privacySettingsEvent as PrivacySettingsEv,
    OfflineSyncPreview as OfflineSyncPreviewEv,
    OfflineSyncCompleted as OfflineSyncCompletedEv,
    BlocklistEvent as BlocklistEv,
    BlocklistChange as BlocklistChangeEv,
    NewsletterJoin as NewsletterJoinEv,
    NewsletterLeave as NewsletterLeaveEv,
    NewsletterMuteChange as NewsletterMuteChangeEv,
    NewsletterLiveUpdate as NewsletterLiveUpdateEV,
    CallOffer as CallOfferEv,
    CallAccept as CallAcceptEv,
    CallPreAccept as CallPreAcceptEv,
    CallTransport as CallTransportEv,
    CallOfferNotice as CallOfferNoticeEv,
    CallRelayLatency as CallRelayLatencyEV,
    CallTerminate as CallTerminateEv,
    UnknownCallEvent as UnknownCallEventEV,
    UndecryptableMessage as UndecryptableMessageEv,
)

log = logging.getLogger(__name__)
if TYPE_CHECKING:
    from .client import NewClient, ClientFactory
EventType = TypeVar("EventType", bound=Message)
EVENT_TO_INT: Dict[Type[Message], int] = {
    QREv: 1,
    PairStatusEv: 2,
    ConnectedEv: 3,
    KeepAliveTimeoutEv: 4,
    KeepAliveRestoredEv: 5,
    LoggedOutEv: 6,
    StreamReplacedEv: 7,
    TemporaryBanEv: 8,
    ConnectFailureEv: 9,
    ClientOutdatedEv: 10,
    StreamErrorEv: 11,
    DisconnectedEv: 12,
    HistorySyncEv: 13,
    NewsLetterMessageMetaEv: 16,
    MessageEv: 17,
    ReceiptEv: 18,
    ChatPresenceEv: 19,
    PresenceEv: 20,
    JoinedGroupEv: 21,
    GroupInfoEv: 22,
    PictureEv: 23,
    IdentityChangeEv: 24,
    PrivacySettingsEv: 25,
    OfflineSyncPreviewEv: 26,
    OfflineSyncCompletedEv: 27,
    BlocklistEv: 30,
    BlocklistChangeEv: 31,
    NewsletterJoinEv: 32,
    NewsletterLeaveEv: 33,
    NewsletterMuteChangeEv: 34,
    NewsletterLiveUpdateEV: 35,
    CallOfferEv: 36,
    CallAcceptEv: 37,
    CallPreAcceptEv: 38,
    CallTransportEv: 39,
    CallOfferNoticeEv: 40,
    CallRelayLatencyEV: 41,
    CallTerminateEv: 42,
    UnknownCallEventEV: 43,
    UndecryptableMessageEv: 44,
}
INT_TO_EVENT: Dict[int, Type[Message]] = {code: ev for ev, code in EVENT_TO_INT.items()}

event = EventThread()


class EventsManager:
    def __init__(self, client_factory: ClientFactory):
        self.client_factory = client_factory
        self.list_func: Dict[int, Callable[[NewClient, Message], None]] = {}

    def __call__(
        self, event: Type[EventType]
    ) -> Callable[[Callable[[NewClient, EventType], None]], None]:
        """
        Registers a callback function for a specific event type.

        :param event: The type of event to register the callback for.
        :type event: Type[EventType]
        :return: A decorator that registers the callback function.
        :rtype: Callablae[[Callable[[NewClient, EventType], None]], None]
        """

        def callback(func: Callable[[NewClient, EventType], None]) -> None:
            self.list_func.update({EVENT_TO_INT[event]: func})

        return callback


class Event:
    def __init__(self, client: NewClient):
        """
        Initializes the Event class with a client of type NewClient.
        Also sets up a default blocking function and an empty dictionary for list functions.

        :param client: An instance of the NewClient class
        :type client: NewClient
        """
        self.client = client
        self.blocking_func = self.blocking(self.default_blocking)
        self.list_func: Dict[int, Callable[[NewClient, Message], None]] = {}
        self._qr = self.__onqr

    def execute(self, binary: int, size: int, code: int):
        """Executes a function from the list of functions based on the given code.

        :param binary: The binary data to be processed by the function.
        :type binary: int
        :param size: The size of the binary data.
        :type size: int
        :param code: The index of the function to be executed from the list of functions.
        :type code: int
        """
        if code not in INT_TO_EVENT:
            raise UnsupportedEvent()
        message = INT_TO_EVENT[code].FromString(ctypes.string_at(binary, size))
        self.list_func[code](self.client, message)

    def __onqr(self, _: NewClient, data_qr: bytes):
        """
        Handles QR code generation and display.

        :param _: The client instance (not used in the function).
        :type _: NewClient
        :param data_qr: The data to be encoded in the QR code.
        :type data_qr: bytes
        """
        segno.make_qr(data_qr).terminal(compact=True)

    def qr(self, f: Callable[[NewClient, bytes], None]):
        """
        Sets a callback function for handling QR code data.

        :param f: The callback function that takes a NewClient instance and QR code data in bytes.
        :type f: Callable[[NewClient, bytes], None]
        """
        self._qr = f

    @property
    def blocking(self):
        def block(f: Callable[[NewClient], None]):
            """This method assigns a blocking function to process a new client and prevents the process from ending.

            :param f: A function that takes a new client as an argument and returns nothing.
            :type f: Callable[[NewClient], None]
            """
            self.blocking_func = lambda _: f(self.client)
            return self.blocking_func

        return block

    @classmethod
    def default_blocking(cls, _):
        log.debug("🚧 The blocking function has been called.")
        event.wait()
        log.debug("🚦 The function has been unblocked.")

    def __call__(
        self, event: Type[EventType]
    ) -> Callable[[Callable[[NewClient, EventType], None]], None]:
        """
        Registers a callback function for a specific event type.

        :param event: The type of event to register the callback for.
        :type event: Type[EventType]
        :return: A decorator that registers the callback function.
        :rtype: Callable[[Callable[[NewClient, EventType], None]], None]
        """

        def callback(func: Callable[[NewClient, EventType], None]) -> None:
            self.list_func.update({EVENT_TO_INT[event]: func})

        return callback



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class DeviceCapabilities(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ChatLockSupportLevel:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ChatLockSupportLevelEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[DeviceCapabilities._ChatLockSupportLevel.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        NONE: DeviceCapabilities._ChatLockSupportLevel.ValueType  # 0
        MINIMAL: DeviceCapabilities._ChatLockSupportLevel.ValueType  # 1
        FULL: DeviceCapabilities._ChatLockSupportLevel.ValueType  # 2

    class ChatLockSupportLevel(_ChatLockSupportLevel, metaclass=_ChatLockSupportLevelEnumTypeWrapper): ...
    NONE: DeviceCapabilities.ChatLockSupportLevel.ValueType  # 0
    MINIMAL: DeviceCapabilities.ChatLockSupportLevel.ValueType  # 1
    FULL: DeviceCapabilities.ChatLockSupportLevel.ValueType  # 2

    @typing.final
    class LIDMigration(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CHATDBMIGRATIONTIMESTAMP_FIELD_NUMBER: builtins.int
        chatDbMigrationTimestamp: builtins.int
        def __init__(
            self,
            *,
            chatDbMigrationTimestamp: builtins.int | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["chatDbMigrationTimestamp", b"chatDbMigrationTimestamp"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["chatDbMigrationTimestamp", b"chatDbMigrationTimestamp"]) -> None: ...

    CHATLOCKSUPPORTLEVEL_FIELD_NUMBER: builtins.int
    LIDMIGRATION_FIELD_NUMBER: builtins.int
    chatLockSupportLevel: global___DeviceCapabilities.ChatLockSupportLevel.ValueType
    @property
    def lidMigration(self) -> global___DeviceCapabilities.LIDMigration: ...
    def __init__(
        self,
        *,
        chatLockSupportLevel: global___DeviceCapabilities.ChatLockSupportLevel.ValueType | None = ...,
        lidMigration: global___DeviceCapabilities.LIDMigration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["chatLockSupportLevel", b"chatLockSupportLevel", "lidMigration", b"lidMigration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["chatLockSupportLevel", b"chatLockSupportLevel", "lidMigration", b"lidMigration"]) -> None: ...

global___DeviceCapabilities = DeviceCapabilities



from io import BytesIO
from typing import Tuple
from PIL import Image


def crop_image(image: Image.Image) -> Image.Image:
    """
    Crops an image to make it square. If the image is already square, it is returned as is.
    If the image is not square, the longer dimension is cropped equally from both sides to make it square.

    :param image: An image that needs to be cropped
    :type image: Image.Image
    :return: A square cropped image
    :rtype: Image.Image
    """
    width, height = image.size
    if width == height:
        return image
    offset = int(abs(height - width) / 2)
    if width > height:
        image = image.crop([offset, 0, width - offset, height])  # type: ignore
    else:
        image = image.crop([0, offset, width, height - offset])  # type: ignore
    return image


def AspectRatioMethod(width: int | float, height: int | float, res: int = 1280) -> Tuple[int, int]:
    """Calculate the aspect ratio of a given width and height with respect to a resolution.

    :param width: The width of the given area.
    :type width: int | float
    :param height: The height of the given area.
    :type height: int | float
    :param res: The resolution to calculate the aspect ratio with, defaults to 1280.
    :type res: int, optional
    :return: A tuple containing the calculated width and height based on the aspect ratio.
    :rtype: Tuple[int, int]
    """
    if width > height:
        return (res, int(width / (width / res)))
    elif width < height:
        return (int(width / (height / res)), res)
    return (res, res)


def sticker_scaler(fn: str | BytesIO | Image.Image):
    """
    This function rescales an image to a maximum dimension of 512 pixels while maintaining the aspect ratio.
    The function takes the filename of the image as an input and returns the rescaled image.

    :param fn: Filename of the image to be rescaled
    :type fn: str
    :return: Rescaled image
    :rtype: PIL.Image.Image
    """
    img = fn if isinstance(fn, Image.Image) else Image.open(fn)
    width, height = AspectRatioMethod(*img.size, 512)
    return img.resize((int(width), int(height)))


def auto_sticker(fn: str | BytesIO | Image.Image):
    """
    This function creates a new sticker image with a specified size (512 x 512).
    The original image is placed at the center of the new sticker.

    :param fn: The file name of the original image.
    :type fn: str
    :return: The new sticker image with the original image at the center.
    :rtype: Image object
    """
    img = fn if isinstance(fn, Image.Image) else Image.open(fn)
    new_layer = Image.new("RGBA", (512, 512), color=(0, 0, 0, 0))
    new_layer.paste(img, (256 - (int(img.width / 2)), 256 - (int(img.height / 2))))
    return new_layer


def original_sticker(image: str | BytesIO | Image.Image):
    """
    This function creates a new sticker image with a square background.
    The original image is placed at the center of the new sticker.

    :param image: The file name of the original image.
    :return: The new sticker image with the original image at the center (uncropped).
    :rtype: Image object
    """
    img = image if isinstance(image, Image.Image) else Image.open(image)
    orig_width, orig_height = img.size
    square_size = max(orig_width, orig_height)
    square_img = Image.new("RGBA", (square_size, square_size), (0, 0, 0, 0))
    x_offset = (square_size - orig_width) // 2
    y_offset = (square_size - orig_height) // 2
    square_img.paste(img, (x_offset, y_offset), img if img.mode == "RGBA" else None)
    return square_img



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Subprotocol(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAYLOAD_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    payload: builtins.bytes
    version: builtins.int
    def __init__(
        self,
        *,
        payload: builtins.bytes | None = ...,
        version: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["payload", b"payload", "version", b"version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["payload", b"payload", "version", b"version"]) -> None: ...

global___Subprotocol = Subprotocol



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ICDCIdentityList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEQ_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    DEVICES_FIELD_NUMBER: builtins.int
    SIGNINGDEVICEINDEX_FIELD_NUMBER: builtins.int
    seq: builtins.int
    timestamp: builtins.int
    signingDeviceIndex: builtins.int
    @property
    def devices(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.bytes]: ...
    def __init__(
        self,
        *,
        seq: builtins.int | None = ...,
        timestamp: builtins.int | None = ...,
        devices: collections.abc.Iterable[builtins.bytes] | None = ...,
        signingDeviceIndex: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["seq", b"seq", "signingDeviceIndex", b"signingDeviceIndex", "timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["devices", b"devices", "seq", b"seq", "signingDeviceIndex", b"signingDeviceIndex", "timestamp", b"timestamp"]) -> None: ...

global___ICDCIdentityList = ICDCIdentityList

@typing.final
class SignedICDCIdentityList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DETAILS_FIELD_NUMBER: builtins.int
    SIGNATURE_FIELD_NUMBER: builtins.int
    details: builtins.bytes
    signature: builtins.bytes
    def __init__(
        self,
        *,
        details: builtins.bytes | None = ...,
        signature: builtins.bytes | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["details", b"details", "signature", b"signature"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["details", b"details", "signature", b"signature"]) -> None: ...

global___SignedICDCIdentityList = SignedICDCIdentityList



import os
from typing import Dict
import platform


def arch_normalizer(arch_: str) -> str:
    """
    Normalizes architecture names to a standardized format.

    :param arch_: The architecture name to be normalized.
    :type arch_: str
    :return: The normalized architecture name.
    :rtype: str
    """
    arch: Dict[str, str] = {
        "aarch64": "arm64",
        "x86_64": "amd64",
    }
    return arch.get(arch_, arch_)


def generated_name(os_name="", arch_name=""):
    """
    Generates a standardized filename based on the operating system and architecture.

    :param os_name: The name of the operating system, defaults to an empty string.
    :type os_name: str, optional
    :param arch_name: The name of the architecture, defaults to an empty string.
    :type arch_name: str, optional
    :return: The generated filename.
    :rtype: str
    """
    os_name = os_name or platform.system().lower()
    arch_name = arch_normalizer(arch_name or platform.machine().lower())
    if os_name == "windows":
        ext = "dll"
    elif os_name == "linux":
        is_android = "android" in os.popen("uname -a").read().strip().lower()
        if is_android:
            os_name = "android"
        ext = "so"
    elif os_name == "darwin":
        ext = "dylib"
    else:
        ext = "so"
    return f"neonize-{os_name}-{arch_name}.{ext}"



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import waChatLockSettings.WAProtobufsChatLockSettings_pb2
import waCommon.WACommon_pb2
import waE2E.WAWebProtobufsE2E_pb2
import waSyncAction.WASyncAction_pb2
import waWeb.WAWebProtobufsWeb_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _MediaVisibility:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MediaVisibilityEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MediaVisibility.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DEFAULT: _MediaVisibility.ValueType  # 0
    OFF: _MediaVisibility.ValueType  # 1
    ON: _MediaVisibility.ValueType  # 2

class MediaVisibility(_MediaVisibility, metaclass=_MediaVisibilityEnumTypeWrapper): ...

DEFAULT: MediaVisibility.ValueType  # 0
OFF: MediaVisibility.ValueType  # 1
ON: MediaVisibility.ValueType  # 2
global___MediaVisibility = MediaVisibility

class _PrivacySystemMessage:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PrivacySystemMessageEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PrivacySystemMessage.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    E2EE_MSG: _PrivacySystemMessage.ValueType  # 1
    NE2EE_SELF: _PrivacySystemMessage.ValueType  # 2
    NE2EE_OTHER: _PrivacySystemMessage.ValueType  # 3

class PrivacySystemMessage(_PrivacySystemMessage, metaclass=_PrivacySystemMessageEnumTypeWrapper): ...

E2EE_MSG: PrivacySystemMessage.ValueType  # 1
NE2EE_SELF: PrivacySystemMessage.ValueType  # 2
NE2EE_OTHER: PrivacySystemMessage.ValueType  # 3
global___PrivacySystemMessage = PrivacySystemMessage

@typing.final
class HistorySync(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _BotAIWaitListState:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _BotAIWaitListStateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[HistorySync._BotAIWaitListState.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        IN_WAITLIST: HistorySync._BotAIWaitListState.ValueType  # 0
        AI_AVAILABLE: HistorySync._BotAIWaitListState.ValueType  # 1

    class BotAIWaitListState(_BotAIWaitListState, metaclass=_BotAIWaitListStateEnumTypeWrapper): ...
    IN_WAITLIST: HistorySync.BotAIWaitListState.ValueType  # 0
    AI_AVAILABLE: HistorySync.BotAIWaitListState.ValueType  # 1

    class _HistorySyncType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _HistorySyncTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[HistorySync._HistorySyncType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        INITIAL_BOOTSTRAP: HistorySync._HistorySyncType.ValueType  # 0
        INITIAL_STATUS_V3: HistorySync._HistorySyncType.ValueType  # 1
        FULL: HistorySync._HistorySyncType.ValueType  # 2
        RECENT: HistorySync._HistorySyncType.ValueType  # 3
        PUSH_NAME: HistorySync._HistorySyncType.ValueType  # 4
        NON_BLOCKING_DATA: HistorySync._HistorySyncType.ValueType  # 5
        ON_DEMAND: HistorySync._HistorySyncType.ValueType  # 6

    class HistorySyncType(_HistorySyncType, metaclass=_HistorySyncTypeEnumTypeWrapper): ...
    INITIAL_BOOTSTRAP: HistorySync.HistorySyncType.ValueType  # 0
    INITIAL_STATUS_V3: HistorySync.HistorySyncType.ValueType  # 1
    FULL: HistorySync.HistorySyncType.ValueType  # 2
    RECENT: HistorySync.HistorySyncType.ValueType  # 3
    PUSH_NAME: HistorySync.HistorySyncType.ValueType  # 4
    NON_BLOCKING_DATA: HistorySync.HistorySyncType.ValueType  # 5
    ON_DEMAND: HistorySync.HistorySyncType.ValueType  # 6

    SYNCTYPE_FIELD_NUMBER: builtins.int
    CONVERSATIONS_FIELD_NUMBER: builtins.int
    STATUSV3MESSAGES_FIELD_NUMBER: builtins.int
    CHUNKORDER_FIELD_NUMBER: builtins.int
    PROGRESS_FIELD_NUMBER: builtins.int
    PUSHNAMES_FIELD_NUMBER: builtins.int
    GLOBALSETTINGS_FIELD_NUMBER: builtins.int
    THREADIDUSERSECRET_FIELD_NUMBER: builtins.int
    THREADDSTIMEFRAMEOFFSET_FIELD_NUMBER: builtins.int
    RECENTSTICKERS_FIELD_NUMBER: builtins.int
    PASTPARTICIPANTS_FIELD_NUMBER: builtins.int
    CALLLOGRECORDS_FIELD_NUMBER: builtins.int
    AIWAITLISTSTATE_FIELD_NUMBER: builtins.int
    PHONENUMBERTOLIDMAPPINGS_FIELD_NUMBER: builtins.int
    COMPANIONMETANONCE_FIELD_NUMBER: builtins.int
    SHAREABLECHATIDENTIFIERENCRYPTIONKEY_FIELD_NUMBER: builtins.int
    ACCOUNTS_FIELD_NUMBER: builtins.int
    syncType: global___HistorySync.HistorySyncType.ValueType
    chunkOrder: builtins.int
    progress: builtins.int
    threadIDUserSecret: builtins.bytes
    threadDsTimeframeOffset: builtins.int
    aiWaitListState: global___HistorySync.BotAIWaitListState.ValueType
    companionMetaNonce: builtins.str
    shareableChatIdentifierEncryptionKey: builtins.bytes
    @property
    def conversations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Conversation]: ...
    @property
    def statusV3Messages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[waWeb.WAWebProtobufsWeb_pb2.WebMessageInfo]: ...
    @property
    def pushnames(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Pushname]: ...
    @property
    def globalSettings(self) -> global___GlobalSettings: ...
    @property
    def recentStickers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StickerMetadata]: ...
    @property
    def pastParticipants(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PastParticipants]: ...
    @property
    def callLogRecords(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[waSyncAction.WASyncAction_pb2.CallLogRecord]: ...
    @property
    def phoneNumberToLidMappings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PhoneNumberToLIDMapping]: ...
    @property
    def accounts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Account]: ...
    def __init__(
        self,
        *,
        syncType: global___HistorySync.HistorySyncType.ValueType | None = ...,
        conversations: collections.abc.Iterable[global___Conversation] | None = ...,
        statusV3Messages: collections.abc.Iterable[waWeb.WAWebProtobufsWeb_pb2.WebMessageInfo] | None = ...,
        chunkOrder: builtins.int | None = ...,
        progress: builtins.int | None = ...,
        pushnames: collections.abc.Iterable[global___Pushname] | None = ...,
        globalSettings: global___GlobalSettings | None = ...,
        threadIDUserSecret: builtins.bytes | None = ...,
        threadDsTimeframeOffset: builtins.int | None = ...,
        recentStickers: collections.abc.Iterable[global___StickerMetadata] | None = ...,
        pastParticipants: collections.abc.Iterable[global___PastParticipants] | None = ...,
        callLogRecords: collections.abc.Iterable[waSyncAction.WASyncAction_pb2.CallLogRecord] | None = ...,
        aiWaitListState: global___HistorySync.BotAIWaitListState.ValueType | None = ...,
        phoneNumberToLidMappings: collections.abc.Iterable[global___PhoneNumberToLIDMapping] | None = ...,
        companionMetaNonce: builtins.str | None = ...,
        shareableChatIdentifierEncryptionKey: builtins.bytes | None = ...,
        accounts: collections.abc.Iterable[global___Account] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["aiWaitListState", b"aiWaitListState", "chunkOrder", b"chunkOrder", "companionMetaNonce", b"companionMetaNonce", "globalSettings", b"globalSettings", "progress", b"progress", "shareableChatIdentifierEncryptionKey", b"shareableChatIdentifierEncryptionKey", "syncType", b"syncType", "threadDsTimeframeOffset", b"threadDsTimeframeOffset", "threadIDUserSecret", b"threadIDUserSecret"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["accounts", b"accounts", "aiWaitListState", b"aiWaitListState", "callLogRecords", b"callLogRecords", "chunkOrder", b"chunkOrder", "companionMetaNonce", b"companionMetaNonce", "conversations", b"conversations", "globalSettings", b"globalSettings", "pastParticipants", b"pastParticipants", "phoneNumberToLidMappings", b"phoneNumberToLidMappings", "progress", b"progress", "pushnames", b"pushnames", "recentStickers", b"recentStickers", "shareableChatIdentifierEncryptionKey", b"shareableChatIdentifierEncryptionKey", "statusV3Messages", b"statusV3Messages", "syncType", b"syncType", "threadDsTimeframeOffset", b"threadDsTimeframeOffset", "threadIDUserSecret", b"threadIDUserSecret"]) -> None: ...

global___HistorySync = HistorySync

@typing.final
class Conversation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _EndOfHistoryTransferType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _EndOfHistoryTransferTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Conversation._EndOfHistoryTransferType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        COMPLETE_BUT_MORE_MESSAGES_REMAIN_ON_PRIMARY: Conversation._EndOfHistoryTransferType.ValueType  # 0
        COMPLETE_AND_NO_MORE_MESSAGE_REMAIN_ON_PRIMARY: Conversation._EndOfHistoryTransferType.ValueType  # 1
        COMPLETE_ON_DEMAND_SYNC_BUT_MORE_MSG_REMAIN_ON_PRIMARY: Conversation._EndOfHistoryTransferType.ValueType  # 2

    class EndOfHistoryTransferType(_EndOfHistoryTransferType, metaclass=_EndOfHistoryTransferTypeEnumTypeWrapper): ...
    COMPLETE_BUT_MORE_MESSAGES_REMAIN_ON_PRIMARY: Conversation.EndOfHistoryTransferType.ValueType  # 0
    COMPLETE_AND_NO_MORE_MESSAGE_REMAIN_ON_PRIMARY: Conversation.EndOfHistoryTransferType.ValueType  # 1
    COMPLETE_ON_DEMAND_SYNC_BUT_MORE_MSG_REMAIN_ON_PRIMARY: Conversation.EndOfHistoryTransferType.ValueType  # 2

    ID_FIELD_NUMBER: builtins.int
    MESSAGES_FIELD_NUMBER: builtins.int
    NEWJID_FIELD_NUMBER: builtins.int
    OLDJID_FIELD_NUMBER: builtins.int
    LASTMSGTIMESTAMP_FIELD_NUMBER: builtins.int
    UNREADCOUNT_FIELD_NUMBER: builtins.int
    READONLY_FIELD_NUMBER: builtins.int
    ENDOFHISTORYTRANSFER_FIELD_NUMBER: builtins.int
    EPHEMERALEXPIRATION_FIELD_NUMBER: builtins.int
    EPHEMERALSETTINGTIMESTAMP_FIELD_NUMBER: builtins.int
    ENDOFHISTORYTRANSFERTYPE_FIELD_NUMBER: builtins.int
    CONVERSATIONTIMESTAMP_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PHASH_FIELD_NUMBER: builtins.int
    NOTSPAM_FIELD_NUMBER: builtins.int
    ARCHIVED_FIELD_NUMBER: builtins.int
    DISAPPEARINGMODE_FIELD_NUMBER: builtins.int
    UNREADMENTIONCOUNT_FIELD_NUMBER: builtins.int
    MARKEDASUNREAD_FIELD_NUMBER: builtins.int
    PARTICIPANT_FIELD_NUMBER: builtins.int
    TCTOKEN_FIELD_NUMBER: builtins.int
    TCTOKENTIMESTAMP_FIELD_NUMBER: builtins.int
    CONTACTPRIMARYIDENTITYKEY_FIELD_NUMBER: builtins.int
    PINNED_FIELD_NUMBER: builtins.int
    MUTEENDTIME_FIELD_NUMBER: builtins.int
    WALLPAPER_FIELD_NUMBER: builtins.int
    MEDIAVISIBILITY_FIELD_NUMBER: builtins.int
    TCTOKENSENDERTIMESTAMP_FIELD_NUMBER: builtins.int
    SUSPENDED_FIELD_NUMBER: builtins.int
    TERMINATED_FIELD_NUMBER: builtins.int
    CREATEDAT_FIELD_NUMBER: builtins.int
    CREATEDBY_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    SUPPORT_FIELD_NUMBER: builtins.int
    ISPARENTGROUP_FIELD_NUMBER: builtins.int
    PARENTGROUPID_FIELD_NUMBER: builtins.int
    ISDEFAULTSUBGROUP_FIELD_NUMBER: builtins.int
    DISPLAYNAME_FIELD_NUMBER: builtins.int
    PNJID_FIELD_NUMBER: builtins.int
    SHAREOWNPN_FIELD_NUMBER: builtins.int
    PNHDUPLICATELIDTHREAD_FIELD_NUMBER: builtins.int
    LIDJID_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    LIDORIGINTYPE_FIELD_NUMBER: builtins.int
    COMMENTSCOUNT_FIELD_NUMBER: builtins.int
    LOCKED_FIELD_NUMBER: builtins.int
    SYSTEMMESSAGETOINSERT_FIELD_NUMBER: builtins.int
    CAPICREATEDGROUP_FIELD_NUMBER: builtins.int
    ACCOUNTLID_FIELD_NUMBER: builtins.int
    LIMITSHARING_FIELD_NUMBER: builtins.int
    LIMITSHARINGSETTINGTIMESTAMP_FIELD_NUMBER: builtins.int
    LIMITSHARINGTRIGGER_FIELD_NUMBER: builtins.int
    LIMITSHARINGINITIATEDBYME_FIELD_NUMBER: builtins.int
    ID: builtins.str
    newJID: builtins.str
    oldJID: builtins.str
    lastMsgTimestamp: builtins.int
    unreadCount: builtins.int
    readOnly: builtins.bool
    endOfHistoryTransfer: builtins.bool
    ephemeralExpiration: builtins.int
    ephemeralSettingTimestamp: builtins.int
    endOfHistoryTransferType: global___Conversation.EndOfHistoryTransferType.ValueType
    conversationTimestamp: builtins.int
    name: builtins.str
    pHash: builtins.str
    notSpam: builtins.bool
    archived: builtins.bool
    unreadMentionCount: builtins.int
    markedAsUnread: builtins.bool
    tcToken: builtins.bytes
    tcTokenTimestamp: builtins.int
    contactPrimaryIdentityKey: builtins.bytes
    pinned: builtins.int
    muteEndTime: builtins.int
    mediaVisibility: global___MediaVisibility.ValueType
    tcTokenSenderTimestamp: builtins.int
    suspended: builtins.bool
    terminated: builtins.bool
    createdAt: builtins.int
    createdBy: builtins.str
    description: builtins.str
    support: builtins.bool
    isParentGroup: builtins.bool
    parentGroupID: builtins.str
    isDefaultSubgroup: builtins.bool
    displayName: builtins.str
    pnJID: builtins.str
    shareOwnPn: builtins.bool
    pnhDuplicateLidThread: builtins.bool
    lidJID: builtins.str
    username: builtins.str
    lidOriginType: builtins.str
    commentsCount: builtins.int
    locked: builtins.bool
    systemMessageToInsert: global___PrivacySystemMessage.ValueType
    capiCreatedGroup: builtins.bool
    accountLid: builtins.str
    limitSharing: builtins.bool
    limitSharingSettingTimestamp: builtins.int
    limitSharingTrigger: waCommon.WACommon_pb2.LimitSharing.Trigger.ValueType
    limitSharingInitiatedByMe: builtins.bool
    @property
    def messages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HistorySyncMsg]: ...
    @property
    def disappearingMode(self) -> waE2E.WAWebProtobufsE2E_pb2.DisappearingMode: ...
    @property
    def participant(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GroupParticipant]: ...
    @property
    def wallpaper(self) -> global___WallpaperSettings: ...
    def __init__(
        self,
        *,
        ID: builtins.str | None = ...,
        messages: collections.abc.Iterable[global___HistorySyncMsg] | None = ...,
        newJID: builtins.str | None = ...,
        oldJID: builtins.str | None = ...,
        lastMsgTimestamp: builtins.int | None = ...,
        unreadCount: builtins.int | None = ...,
        readOnly: builtins.bool | None = ...,
        endOfHistoryTransfer: builtins.bool | None = ...,
        ephemeralExpiration: builtins.int | None = ...,
        ephemeralSettingTimestamp: builtins.int | None = ...,
        endOfHistoryTransferType: global___Conversation.EndOfHistoryTransferType.ValueType | None = ...,
        conversationTimestamp: builtins.int | None = ...,
        name: builtins.str | None = ...,
        pHash: builtins.str | None = ...,
        notSpam: builtins.bool | None = ...,
        archived: builtins.bool | None = ...,
        disappearingMode: waE2E.WAWebProtobufsE2E_pb2.DisappearingMode | None = ...,
        unreadMentionCount: builtins.int | None = ...,
        markedAsUnread: builtins.bool | None = ...,
        participant: collections.abc.Iterable[global___GroupParticipant] | None = ...,
        tcToken: builtins.bytes | None = ...,
        tcTokenTimestamp: builtins.int | None = ...,
        contactPrimaryIdentityKey: builtins.bytes | None = ...,
        pinned: builtins.int | None = ...,
        muteEndTime: builtins.int | None = ...,
        wallpaper: global___WallpaperSettings | None = ...,
        mediaVisibility: global___MediaVisibility.ValueType | None = ...,
        tcTokenSenderTimestamp: builtins.int | None = ...,
        suspended: builtins.bool | None = ...,
        terminated: builtins.bool | None = ...,
        createdAt: builtins.int | None = ...,
        createdBy: builtins.str | None = ...,
        description: builtins.str | None = ...,
        support: builtins.bool | None = ...,
        isParentGroup: builtins.bool | None = ...,
        parentGroupID: builtins.str | None = ...,
        isDefaultSubgroup: builtins.bool | None = ...,
        displayName: builtins.str | None = ...,
        pnJID: builtins.str | None = ...,
        shareOwnPn: builtins.bool | None = ...,
        pnhDuplicateLidThread: builtins.bool | None = ...,
        lidJID: builtins.str | None = ...,
        username: builtins.str | None = ...,
        lidOriginType: builtins.str | None = ...,
        commentsCount: builtins.int | None = ...,
        locked: builtins.bool | None = ...,
        systemMessageToInsert: global___PrivacySystemMessage.ValueType | None = ...,
        capiCreatedGroup: builtins.bool | None = ...,
        accountLid: builtins.str | None = ...,
        limitSharing: builtins.bool | None = ...,
        limitSharingSettingTimestamp: builtins.int | None = ...,
        limitSharingTrigger: waCommon.WACommon_pb2.LimitSharing.Trigger.ValueType | None = ...,
        limitSharingInitiatedByMe: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ID", b"ID", "accountLid", b"accountLid", "archived", b"archived", "capiCreatedGroup", b"capiCreatedGroup", "commentsCount", b"commentsCount", "contactPrimaryIdentityKey", b"contactPrimaryIdentityKey", "conversationTimestamp", b"conversationTimestamp", "createdAt", b"createdAt", "createdBy", b"createdBy", "description", b"description", "disappearingMode", b"disappearingMode", "displayName", b"displayName", "endOfHistoryTransfer", b"endOfHistoryTransfer", "endOfHistoryTransferType", b"endOfHistoryTransferType", "ephemeralExpiration", b"ephemeralExpiration", "ephemeralSettingTimestamp", b"ephemeralSettingTimestamp", "isDefaultSubgroup", b"isDefaultSubgroup", "isParentGroup", b"isParentGroup", "lastMsgTimestamp", b"lastMsgTimestamp", "lidJID", b"lidJID", "lidOriginType", b"lidOriginType", "limitSharing", b"limitSharing", "limitSharingInitiatedByMe", b"limitSharingInitiatedByMe", "limitSharingSettingTimestamp", b"limitSharingSettingTimestamp", "limitSharingTrigger", b"limitSharingTrigger", "locked", b"locked", "markedAsUnread", b"markedAsUnread", "mediaVisibility", b"mediaVisibility", "muteEndTime", b"muteEndTime", "name", b"name", "newJID", b"newJID", "notSpam", b"notSpam", "oldJID", b"oldJID", "pHash", b"pHash", "parentGroupID", b"parentGroupID", "pinned", b"pinned", "pnJID", b"pnJID", "pnhDuplicateLidThread", b"pnhDuplicateLidThread", "readOnly", b"readOnly", "shareOwnPn", b"shareOwnPn", "support", b"support", "suspended", b"suspended", "systemMessageToInsert", b"systemMessageToInsert", "tcToken", b"tcToken", "tcTokenSenderTimestamp", b"tcTokenSenderTimestamp", "tcTokenTimestamp", b"tcTokenTimestamp", "terminated", b"terminated", "unreadCount", b"unreadCount", "unreadMentionCount", b"unreadMentionCount", "username", b"username", "wallpaper", b"wallpaper"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ID", b"ID", "accountLid", b"accountLid", "archived", b"archived", "capiCreatedGroup", b"capiCreatedGroup", "commentsCount", b"commentsCount", "contactPrimaryIdentityKey", b"contactPrimaryIdentityKey", "conversationTimestamp", b"conversationTimestamp", "createdAt", b"createdAt", "createdBy", b"createdBy", "description", b"description", "disappearingMode", b"disappearingMode", "displayName", b"displayName", "endOfHistoryTransfer", b"endOfHistoryTransfer", "endOfHistoryTransferType", b"endOfHistoryTransferType", "ephemeralExpiration", b"ephemeralExpiration", "ephemeralSettingTimestamp", b"ephemeralSettingTimestamp", "isDefaultSubgroup", b"isDefaultSubgroup", "isParentGroup", b"isParentGroup", "lastMsgTimestamp", b"lastMsgTimestamp", "lidJID", b"lidJID", "lidOriginType", b"lidOriginType", "limitSharing", b"limitSharing", "limitSharingInitiatedByMe", b"limitSharingInitiatedByMe", "limitSharingSettingTimestamp", b"limitSharingSettingTimestamp", "limitSharingTrigger", b"limitSharingTrigger", "locked", b"locked", "markedAsUnread", b"markedAsUnread", "mediaVisibility", b"mediaVisibility", "messages", b"messages", "muteEndTime", b"muteEndTime", "name", b"name", "newJID", b"newJID", "notSpam", b"notSpam", "oldJID", b"oldJID", "pHash", b"pHash", "parentGroupID", b"parentGroupID", "participant", b"participant", "pinned", b"pinned", "pnJID", b"pnJID", "pnhDuplicateLidThread", b"pnhDuplicateLidThread", "readOnly", b"readOnly", "shareOwnPn", b"shareOwnPn", "support", b"support", "suspended", b"suspended", "systemMessageToInsert", b"systemMessageToInsert", "tcToken", b"tcToken", "tcTokenSenderTimestamp", b"tcTokenSenderTimestamp", "tcTokenTimestamp", b"tcTokenTimestamp", "terminated", b"terminated", "unreadCount", b"unreadCount", "unreadMentionCount", b"unreadMentionCount", "username", b"username", "wallpaper", b"wallpaper"]) -> None: ...

global___Conversation = Conversation

@typing.final
class GroupParticipant(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Rank:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _RankEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[GroupParticipant._Rank.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        REGULAR: GroupParticipant._Rank.ValueType  # 0
        ADMIN: GroupParticipant._Rank.ValueType  # 1
        SUPERADMIN: GroupParticipant._Rank.ValueType  # 2

    class Rank(_Rank, metaclass=_RankEnumTypeWrapper): ...
    REGULAR: GroupParticipant.Rank.ValueType  # 0
    ADMIN: GroupParticipant.Rank.ValueType  # 1
    SUPERADMIN: GroupParticipant.Rank.ValueType  # 2

    USERJID_FIELD_NUMBER: builtins.int
    RANK_FIELD_NUMBER: builtins.int
    userJID: builtins.str
    rank: global___GroupParticipant.Rank.ValueType
    def __init__(
        self,
        *,
        userJID: builtins.str | None = ...,
        rank: global___GroupParticipant.Rank.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["rank", b"rank", "userJID", b"userJID"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["rank", b"rank", "userJID", b"userJID"]) -> None: ...

global___GroupParticipant = GroupParticipant

@typing.final
class PastParticipant(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _LeaveReason:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _LeaveReasonEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PastParticipant._LeaveReason.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        LEFT: PastParticipant._LeaveReason.ValueType  # 0
        REMOVED: PastParticipant._LeaveReason.ValueType  # 1

    class LeaveReason(_LeaveReason, metaclass=_LeaveReasonEnumTypeWrapper): ...
    LEFT: PastParticipant.LeaveReason.ValueType  # 0
    REMOVED: PastParticipant.LeaveReason.ValueType  # 1

    USERJID_FIELD_NUMBER: builtins.int
    LEAVEREASON_FIELD_NUMBER: builtins.int
    LEAVETS_FIELD_NUMBER: builtins.int
    userJID: builtins.str
    leaveReason: global___PastParticipant.LeaveReason.ValueType
    leaveTS: builtins.int
    def __init__(
        self,
        *,
        userJID: builtins.str | None = ...,
        leaveReason: global___PastParticipant.LeaveReason.ValueType | None = ...,
        leaveTS: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["leaveReason", b"leaveReason", "leaveTS", b"leaveTS", "userJID", b"userJID"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["leaveReason", b"leaveReason", "leaveTS", b"leaveTS", "userJID", b"userJID"]) -> None: ...

global___PastParticipant = PastParticipant

@typing.final
class PhoneNumberToLIDMapping(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PNJID_FIELD_NUMBER: builtins.int
    LIDJID_FIELD_NUMBER: builtins.int
    pnJID: builtins.str
    lidJID: builtins.str
    def __init__(
        self,
        *,
        pnJID: builtins.str | None = ...,
        lidJID: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["lidJID", b"lidJID", "pnJID", b"pnJID"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["lidJID", b"lidJID", "pnJID", b"pnJID"]) -> None: ...

global___PhoneNumberToLIDMapping = PhoneNumberToLIDMapping

@typing.final
class Account(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LID_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    COUNTRYCODE_FIELD_NUMBER: builtins.int
    ISUSERNAMEDELETED_FIELD_NUMBER: builtins.int
    lid: builtins.str
    username: builtins.str
    countryCode: builtins.str
    isUsernameDeleted: builtins.bool
    def __init__(
        self,
        *,
        lid: builtins.str | None = ...,
        username: builtins.str | None = ...,
        countryCode: builtins.str | None = ...,
        isUsernameDeleted: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["countryCode", b"countryCode", "isUsernameDeleted", b"isUsernameDeleted", "lid", b"lid", "username", b"username"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["countryCode", b"countryCode", "isUsernameDeleted", b"isUsernameDeleted", "lid", b"lid", "username", b"username"]) -> None: ...

global___Account = Account

@typing.final
class HistorySyncMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGE_FIELD_NUMBER: builtins.int
    MSGORDERID_FIELD_NUMBER: builtins.int
    msgOrderID: builtins.int
    @property
    def message(self) -> waWeb.WAWebProtobufsWeb_pb2.WebMessageInfo: ...
    def __init__(
        self,
        *,
        message: waWeb.WAWebProtobufsWeb_pb2.WebMessageInfo | None = ...,
        msgOrderID: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["message", b"message", "msgOrderID", b"msgOrderID"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["message", b"message", "msgOrderID", b"msgOrderID"]) -> None: ...

global___HistorySyncMsg = HistorySyncMsg

@typing.final
class Pushname(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    PUSHNAME_FIELD_NUMBER: builtins.int
    ID: builtins.str
    pushname: builtins.str
    def __init__(
        self,
        *,
        ID: builtins.str | None = ...,
        pushname: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ID", b"ID", "pushname", b"pushname"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ID", b"ID", "pushname", b"pushname"]) -> None: ...

global___Pushname = Pushname

@typing.final
class WallpaperSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILENAME_FIELD_NUMBER: builtins.int
    OPACITY_FIELD_NUMBER: builtins.int
    filename: builtins.str
    opacity: builtins.int
    def __init__(
        self,
        *,
        filename: builtins.str | None = ...,
        opacity: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["filename", b"filename", "opacity", b"opacity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["filename", b"filename", "opacity", b"opacity"]) -> None: ...

global___WallpaperSettings = WallpaperSettings

@typing.final
class GlobalSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIGHTTHEMEWALLPAPER_FIELD_NUMBER: builtins.int
    MEDIAVISIBILITY_FIELD_NUMBER: builtins.int
    DARKTHEMEWALLPAPER_FIELD_NUMBER: builtins.int
    AUTODOWNLOADWIFI_FIELD_NUMBER: builtins.int
    AUTODOWNLOADCELLULAR_FIELD_NUMBER: builtins.int
    AUTODOWNLOADROAMING_FIELD_NUMBER: builtins.int
    SHOWINDIVIDUALNOTIFICATIONSPREVIEW_FIELD_NUMBER: builtins.int
    SHOWGROUPNOTIFICATIONSPREVIEW_FIELD_NUMBER: builtins.int
    DISAPPEARINGMODEDURATION_FIELD_NUMBER: builtins.int
    DISAPPEARINGMODETIMESTAMP_FIELD_NUMBER: builtins.int
    AVATARUSERSETTINGS_FIELD_NUMBER: builtins.int
    FONTSIZE_FIELD_NUMBER: builtins.int
    SECURITYNOTIFICATIONS_FIELD_NUMBER: builtins.int
    AUTOUNARCHIVECHATS_FIELD_NUMBER: builtins.int
    VIDEOQUALITYMODE_FIELD_NUMBER: builtins.int
    PHOTOQUALITYMODE_FIELD_NUMBER: builtins.int
    INDIVIDUALNOTIFICATIONSETTINGS_FIELD_NUMBER: builtins.int
    GROUPNOTIFICATIONSETTINGS_FIELD_NUMBER: builtins.int
    CHATLOCKSETTINGS_FIELD_NUMBER: builtins.int
    CHATDBLIDMIGRATIONTIMESTAMP_FIELD_NUMBER: builtins.int
    mediaVisibility: global___MediaVisibility.ValueType
    showIndividualNotificationsPreview: builtins.bool
    showGroupNotificationsPreview: builtins.bool
    disappearingModeDuration: builtins.int
    disappearingModeTimestamp: builtins.int
    fontSize: builtins.int
    securityNotifications: builtins.bool
    autoUnarchiveChats: builtins.bool
    videoQualityMode: builtins.int
    photoQualityMode: builtins.int
    chatDbLidMigrationTimestamp: builtins.int
    @property
    def lightThemeWallpaper(self) -> global___WallpaperSettings: ...
    @property
    def darkThemeWallpaper(self) -> global___WallpaperSettings: ...
    @property
    def autoDownloadWiFi(self) -> global___AutoDownloadSettings: ...
    @property
    def autoDownloadCellular(self) -> global___AutoDownloadSettings: ...
    @property
    def autoDownloadRoaming(self) -> global___AutoDownloadSettings: ...
    @property
    def avatarUserSettings(self) -> global___AvatarUserSettings: ...
    @property
    def individualNotificationSettings(self) -> global___NotificationSettings: ...
    @property
    def groupNotificationSettings(self) -> global___NotificationSettings: ...
    @property
    def chatLockSettings(self) -> waChatLockSettings.WAProtobufsChatLockSettings_pb2.ChatLockSettings: ...
    def __init__(
        self,
        *,
        lightThemeWallpaper: global___WallpaperSettings | None = ...,
        mediaVisibility: global___MediaVisibility.ValueType | None = ...,
        darkThemeWallpaper: global___WallpaperSettings | None = ...,
        autoDownloadWiFi: global___AutoDownloadSettings | None = ...,
        autoDownloadCellular: global___AutoDownloadSettings | None = ...,
        autoDownloadRoaming: global___AutoDownloadSettings | None = ...,
        showIndividualNotificationsPreview: builtins.bool | None = ...,
        showGroupNotificationsPreview: builtins.bool | None = ...,
        disappearingModeDuration: builtins.int | None = ...,
        disappearingModeTimestamp: builtins.int | None = ...,
        avatarUserSettings: global___AvatarUserSettings | None = ...,
        fontSize: builtins.int | None = ...,
        securityNotifications: builtins.bool | None = ...,
        autoUnarchiveChats: builtins.bool | None = ...,
        videoQualityMode: builtins.int | None = ...,
        photoQualityMode: builtins.int | None = ...,
        individualNotificationSettings: global___NotificationSettings | None = ...,
        groupNotificationSettings: global___NotificationSettings | None = ...,
        chatLockSettings: waChatLockSettings.WAProtobufsChatLockSettings_pb2.ChatLockSettings | None = ...,
        chatDbLidMigrationTimestamp: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["autoDownloadCellular", b"autoDownloadCellular", "autoDownloadRoaming", b"autoDownloadRoaming", "autoDownloadWiFi", b"autoDownloadWiFi", "autoUnarchiveChats", b"autoUnarchiveChats", "avatarUserSettings", b"avatarUserSettings", "chatDbLidMigrationTimestamp", b"chatDbLidMigrationTimestamp", "chatLockSettings", b"chatLockSettings", "darkThemeWallpaper", b"darkThemeWallpaper", "disappearingModeDuration", b"disappearingModeDuration", "disappearingModeTimestamp", b"disappearingModeTimestamp", "fontSize", b"fontSize", "groupNotificationSettings", b"groupNotificationSettings", "individualNotificationSettings", b"individualNotificationSettings", "lightThemeWallpaper", b"lightThemeWallpaper", "mediaVisibility", b"mediaVisibility", "photoQualityMode", b"photoQualityMode", "securityNotifications", b"securityNotifications", "showGroupNotificationsPreview", b"showGroupNotificationsPreview", "showIndividualNotificationsPreview", b"showIndividualNotificationsPreview", "videoQualityMode", b"videoQualityMode"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["autoDownloadCellular", b"autoDownloadCellular", "autoDownloadRoaming", b"autoDownloadRoaming", "autoDownloadWiFi", b"autoDownloadWiFi", "autoUnarchiveChats", b"autoUnarchiveChats", "avatarUserSettings", b"avatarUserSettings", "chatDbLidMigrationTimestamp", b"chatDbLidMigrationTimestamp", "chatLockSettings", b"chatLockSettings", "darkThemeWallpaper", b"darkThemeWallpaper", "disappearingModeDuration", b"disappearingModeDuration", "disappearingModeTimestamp", b"disappearingModeTimestamp", "fontSize", b"fontSize", "groupNotificationSettings", b"groupNotificationSettings", "individualNotificationSettings", b"individualNotificationSettings", "lightThemeWallpaper", b"lightThemeWallpaper", "mediaVisibility", b"mediaVisibility", "photoQualityMode", b"photoQualityMode", "securityNotifications", b"securityNotifications", "showGroupNotificationsPreview", b"showGroupNotificationsPreview", "showIndividualNotificationsPreview", b"showIndividualNotificationsPreview", "videoQualityMode", b"videoQualityMode"]) -> None: ...

global___GlobalSettings = GlobalSettings

@typing.final
class AutoDownloadSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOWNLOADIMAGES_FIELD_NUMBER: builtins.int
    DOWNLOADAUDIO_FIELD_NUMBER: builtins.int
    DOWNLOADVIDEO_FIELD_NUMBER: builtins.int
    DOWNLOADDOCUMENTS_FIELD_NUMBER: builtins.int
    downloadImages: builtins.bool
    downloadAudio: builtins.bool
    downloadVideo: builtins.bool
    downloadDocuments: builtins.bool
    def __init__(
        self,
        *,
        downloadImages: builtins.bool | None = ...,
        downloadAudio: builtins.bool | None = ...,
        downloadVideo: builtins.bool | None = ...,
        downloadDocuments: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["downloadAudio", b"downloadAudio", "downloadDocuments", b"downloadDocuments", "downloadImages", b"downloadImages", "downloadVideo", b"downloadVideo"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["downloadAudio", b"downloadAudio", "downloadDocuments", b"downloadDocuments", "downloadImages", b"downloadImages", "downloadVideo", b"downloadVideo"]) -> None: ...

global___AutoDownloadSettings = AutoDownloadSettings

@typing.final
class StickerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    FILESHA256_FIELD_NUMBER: builtins.int
    FILEENCSHA256_FIELD_NUMBER: builtins.int
    MEDIAKEY_FIELD_NUMBER: builtins.int
    MIMETYPE_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    WIDTH_FIELD_NUMBER: builtins.int
    DIRECTPATH_FIELD_NUMBER: builtins.int
    FILELENGTH_FIELD_NUMBER: builtins.int
    WEIGHT_FIELD_NUMBER: builtins.int
    LASTSTICKERSENTTS_FIELD_NUMBER: builtins.int
    ISLOTTIE_FIELD_NUMBER: builtins.int
    URL: builtins.str
    fileSHA256: builtins.bytes
    fileEncSHA256: builtins.bytes
    mediaKey: builtins.bytes
    mimetype: builtins.str
    height: builtins.int
    width: builtins.int
    directPath: builtins.str
    fileLength: builtins.int
    weight: builtins.float
    lastStickerSentTS: builtins.int
    isLottie: builtins.bool
    def __init__(
        self,
        *,
        URL: builtins.str | None = ...,
        fileSHA256: builtins.bytes | None = ...,
        fileEncSHA256: builtins.bytes | None = ...,
        mediaKey: builtins.bytes | None = ...,
        mimetype: builtins.str | None = ...,
        height: builtins.int | None = ...,
        width: builtins.int | None = ...,
        directPath: builtins.str | None = ...,
        fileLength: builtins.int | None = ...,
        weight: builtins.float | None = ...,
        lastStickerSentTS: builtins.int | None = ...,
        isLottie: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["URL", b"URL", "directPath", b"directPath", "fileEncSHA256", b"fileEncSHA256", "fileLength", b"fileLength", "fileSHA256", b"fileSHA256", "height", b"height", "isLottie", b"isLottie", "lastStickerSentTS", b"lastStickerSentTS", "mediaKey", b"mediaKey", "mimetype", b"mimetype", "weight", b"weight", "width", b"width"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["URL", b"URL", "directPath", b"directPath", "fileEncSHA256", b"fileEncSHA256", "fileLength", b"fileLength", "fileSHA256", b"fileSHA256", "height", b"height", "isLottie", b"isLottie", "lastStickerSentTS", b"lastStickerSentTS", "mediaKey", b"mediaKey", "mimetype", b"mimetype", "weight", b"weight", "width", b"width"]) -> None: ...

global___StickerMetadata = StickerMetadata

@typing.final
class PastParticipants(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUPJID_FIELD_NUMBER: builtins.int
    PASTPARTICIPANTS_FIELD_NUMBER: builtins.int
    groupJID: builtins.str
    @property
    def pastParticipants(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PastParticipant]: ...
    def __init__(
        self,
        *,
        groupJID: builtins.str | None = ...,
        pastParticipants: collections.abc.Iterable[global___PastParticipant] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["groupJID", b"groupJID"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["groupJID", b"groupJID", "pastParticipants", b"pastParticipants"]) -> None: ...

global___PastParticipants = PastParticipants

@typing.final
class AvatarUserSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FBID_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    FBID: builtins.str
    password: builtins.str
    def __init__(
        self,
        *,
        FBID: builtins.str | None = ...,
        password: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["FBID", b"FBID", "password", b"password"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["FBID", b"FBID", "password", b"password"]) -> None: ...

global___AvatarUserSettings = AvatarUserSettings

@typing.final
class NotificationSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGEVIBRATE_FIELD_NUMBER: builtins.int
    MESSAGEPOPUP_FIELD_NUMBER: builtins.int
    MESSAGELIGHT_FIELD_NUMBER: builtins.int
    LOWPRIORITYNOTIFICATIONS_FIELD_NUMBER: builtins.int
    REACTIONSMUTED_FIELD_NUMBER: builtins.int
    CALLVIBRATE_FIELD_NUMBER: builtins.int
    messageVibrate: builtins.str
    messagePopup: builtins.str
    messageLight: builtins.str
    lowPriorityNotifications: builtins.bool
    reactionsMuted: builtins.bool
    callVibrate: builtins.str
    def __init__(
        self,
        *,
        messageVibrate: builtins.str | None = ...,
        messagePopup: builtins.str | None = ...,
        messageLight: builtins.str | None = ...,
        lowPriorityNotifications: builtins.bool | None = ...,
        reactionsMuted: builtins.bool | None = ...,
        callVibrate: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["callVibrate", b"callVibrate", "lowPriorityNotifications", b"lowPriorityNotifications", "messageLight", b"messageLight", "messagePopup", b"messagePopup", "messageVibrate", b"messageVibrate", "reactionsMuted", b"reactionsMuted"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["callVibrate", b"callVibrate", "lowPriorityNotifications", b"lowPriorityNotifications", "messageLight", b"messageLight", "messagePopup", b"messagePopup", "messageVibrate", b"messageVibrate", "reactionsMuted", b"reactionsMuted"]) -> None: ...

global___NotificationSettings = NotificationSettings



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waArmadilloTransportEvent/WAArmadilloTransportEvent.proto
# Protobuf Python Version: 5.28.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    2,
    '',
    'waArmadilloTransportEvent/WAArmadilloTransportEvent.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9waArmadilloTransportEvent/WAArmadilloTransportEvent.proto\x12\x19WAArmadilloTransportEvent\"\xdb\x06\n\x0eTransportEvent\x12L\n\x0bplaceholder\x18\x01 \x01(\x0b\x32\x35.WAArmadilloTransportEvent.TransportEvent.PlaceholderH\x00\x12@\n\x05\x65vent\x18\x02 \x01(\x0b\x32/.WAArmadilloTransportEvent.TransportEvent.EventH\x00\x1a\x9a\x04\n\x05\x45vent\x12T\n\x0c\x64\x65viceChange\x18\x01 \x01(\x0b\x32<.WAArmadilloTransportEvent.TransportEvent.Event.DeviceChangeH\x00\x12N\n\ticdcAlert\x18\x02 \x01(\x0b\x32\x39.WAArmadilloTransportEvent.TransportEvent.Event.IcdcAlertH\x00\x1a\x86\x01\n\tIcdcAlert\x12L\n\x04type\x18\x01 \x01(\x0e\x32>.WAArmadilloTransportEvent.TransportEvent.Event.IcdcAlert.Type\"+\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\x0c\n\x08\x44\x45TECTED\x10\x01\x12\x0b\n\x07\x43LEARED\x10\x02\x1a\xd8\x01\n\x0c\x44\x65viceChange\x12O\n\x04type\x18\x01 \x01(\x0e\x32\x41.WAArmadilloTransportEvent.TransportEvent.Event.DeviceChange.Type\x12\x12\n\ndeviceName\x18\x02 \x01(\t\x12\x16\n\x0e\x64\x65vicePlatform\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65viceModel\x18\x04 \x01(\t\"6\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05\x41\x44\x44\x45\x44\x10\x01\x12\x0b\n\x07REMOVED\x10\x02\x12\x0c\n\x08REPLACED\x10\x03\x42\x07\n\x05\x65vent\x1a\x90\x01\n\x0bPlaceholder\x12H\n\x04type\x18\x01 \x01(\x0e\x32:.WAArmadilloTransportEvent.TransportEvent.Placeholder.Type\"7\n\x04Type\x12\x16\n\x12\x44\x45\x43RYPTION_FAILURE\x10\x01\x12\x17\n\x13UNAVAILABLE_MESSAGE\x10\x02\x42\t\n\x07\x63ontentB5Z3go.mau.fi/whatsmeow/proto/waArmadilloTransportEvent')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waArmadilloTransportEvent.WAArmadilloTransportEvent_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3go.mau.fi/whatsmeow/proto/waArmadilloTransportEvent'
  _globals['_TRANSPORTEVENT']._serialized_start=89
  _globals['_TRANSPORTEVENT']._serialized_end=948
  _globals['_TRANSPORTEVENT_EVENT']._serialized_start=252
  _globals['_TRANSPORTEVENT_EVENT']._serialized_end=790
  _globals['_TRANSPORTEVENT_EVENT_ICDCALERT']._serialized_start=428
  _globals['_TRANSPORTEVENT_EVENT_ICDCALERT']._serialized_end=562
  _globals['_TRANSPORTEVENT_EVENT_ICDCALERT_TYPE']._serialized_start=519
  _globals['_TRANSPORTEVENT_EVENT_ICDCALERT_TYPE']._serialized_end=562
  _globals['_TRANSPORTEVENT_EVENT_DEVICECHANGE']._serialized_start=565
  _globals['_TRANSPORTEVENT_EVENT_DEVICECHANGE']._serialized_end=781
  _globals['_TRANSPORTEVENT_EVENT_DEVICECHANGE_TYPE']._serialized_start=727
  _globals['_TRANSPORTEVENT_EVENT_DEVICECHANGE_TYPE']._serialized_end=781
  _globals['_TRANSPORTEVENT_PLACEHOLDER']._serialized_start=793
  _globals['_TRANSPORTEVENT_PLACEHOLDER']._serialized_end=937
  _globals['_TRANSPORTEVENT_PLACEHOLDER_TYPE']._serialized_start=882
  _globals['_TRANSPORTEVENT_PLACEHOLDER_TYPE']._serialized_end=937
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _HostedState:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _HostedStateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_HostedState.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    E2EE: _HostedState.ValueType  # 0
    HOSTED: _HostedState.ValueType  # 1

class HostedState(_HostedState, metaclass=_HostedStateEnumTypeWrapper): ...

E2EE: HostedState.ValueType  # 0
HOSTED: HostedState.ValueType  # 1
global___HostedState = HostedState

@typing.final
class FingerprintData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUBLICKEY_FIELD_NUMBER: builtins.int
    PNIDENTIFIER_FIELD_NUMBER: builtins.int
    LIDIDENTIFIER_FIELD_NUMBER: builtins.int
    USERNAMEIDENTIFIER_FIELD_NUMBER: builtins.int
    HOSTEDSTATE_FIELD_NUMBER: builtins.int
    HASHEDPUBLICKEY_FIELD_NUMBER: builtins.int
    publicKey: builtins.bytes
    pnIdentifier: builtins.bytes
    lidIdentifier: builtins.bytes
    usernameIdentifier: builtins.bytes
    hostedState: global___HostedState.ValueType
    hashedPublicKey: builtins.bytes
    def __init__(
        self,
        *,
        publicKey: builtins.bytes | None = ...,
        pnIdentifier: builtins.bytes | None = ...,
        lidIdentifier: builtins.bytes | None = ...,
        usernameIdentifier: builtins.bytes | None = ...,
        hostedState: global___HostedState.ValueType | None = ...,
        hashedPublicKey: builtins.bytes | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["hashedPublicKey", b"hashedPublicKey", "hostedState", b"hostedState", "lidIdentifier", b"lidIdentifier", "pnIdentifier", b"pnIdentifier", "publicKey", b"publicKey", "usernameIdentifier", b"usernameIdentifier"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["hashedPublicKey", b"hashedPublicKey", "hostedState", b"hostedState", "lidIdentifier", b"lidIdentifier", "pnIdentifier", b"pnIdentifier", "publicKey", b"publicKey", "usernameIdentifier", b"usernameIdentifier"]) -> None: ...

global___FingerprintData = FingerprintData

@typing.final
class CombinedFingerprint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    LOCALFINGERPRINT_FIELD_NUMBER: builtins.int
    REMOTEFINGERPRINT_FIELD_NUMBER: builtins.int
    version: builtins.int
    @property
    def localFingerprint(self) -> global___FingerprintData: ...
    @property
    def remoteFingerprint(self) -> global___FingerprintData: ...
    def __init__(
        self,
        *,
        version: builtins.int | None = ...,
        localFingerprint: global___FingerprintData | None = ...,
        remoteFingerprint: global___FingerprintData | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["localFingerprint", b"localFingerprint", "remoteFingerprint", b"remoteFingerprint", "version", b"version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["localFingerprint", b"localFingerprint", "remoteFingerprint", b"remoteFingerprint", "version", b"version"]) -> None: ...

global___CombinedFingerprint = CombinedFingerprint



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import waCommon.WACommon_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class MessageTransport(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Payload(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        APPLICATIONPAYLOAD_FIELD_NUMBER: builtins.int
        FUTUREPROOF_FIELD_NUMBER: builtins.int
        futureProof: waCommon.WACommon_pb2.FutureProofBehavior.ValueType
        @property
        def applicationPayload(self) -> waCommon.WACommon_pb2.SubProtocol: ...
        def __init__(
            self,
            *,
            applicationPayload: waCommon.WACommon_pb2.SubProtocol | None = ...,
            futureProof: waCommon.WACommon_pb2.FutureProofBehavior.ValueType | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["applicationPayload", b"applicationPayload", "futureProof", b"futureProof"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["applicationPayload", b"applicationPayload", "futureProof", b"futureProof"]) -> None: ...

    @typing.final
    class Protocol(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class Ancillary(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            @typing.final
            class BackupDirective(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                class _ActionType:
                    ValueType = typing.NewType("ValueType", builtins.int)
                    V: typing_extensions.TypeAlias = ValueType

                class _ActionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MessageTransport.Protocol.Ancillary.BackupDirective._ActionType.ValueType], builtins.type):
                    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
                    NOOP: MessageTransport.Protocol.Ancillary.BackupDirective._ActionType.ValueType  # 0
                    UPSERT: MessageTransport.Protocol.Ancillary.BackupDirective._ActionType.ValueType  # 1
                    DELETE: MessageTransport.Protocol.Ancillary.BackupDirective._ActionType.ValueType  # 2
                    UPSERT_AND_DELETE: MessageTransport.Protocol.Ancillary.BackupDirective._ActionType.ValueType  # 3

                class ActionType(_ActionType, metaclass=_ActionTypeEnumTypeWrapper): ...
                NOOP: MessageTransport.Protocol.Ancillary.BackupDirective.ActionType.ValueType  # 0
                UPSERT: MessageTransport.Protocol.Ancillary.BackupDirective.ActionType.ValueType  # 1
                DELETE: MessageTransport.Protocol.Ancillary.BackupDirective.ActionType.ValueType  # 2
                UPSERT_AND_DELETE: MessageTransport.Protocol.Ancillary.BackupDirective.ActionType.ValueType  # 3

                MESSAGEID_FIELD_NUMBER: builtins.int
                ACTIONTYPE_FIELD_NUMBER: builtins.int
                SUPPLEMENTALKEY_FIELD_NUMBER: builtins.int
                messageID: builtins.str
                actionType: global___MessageTransport.Protocol.Ancillary.BackupDirective.ActionType.ValueType
                supplementalKey: builtins.str
                def __init__(
                    self,
                    *,
                    messageID: builtins.str | None = ...,
                    actionType: global___MessageTransport.Protocol.Ancillary.BackupDirective.ActionType.ValueType | None = ...,
                    supplementalKey: builtins.str | None = ...,
                ) -> None: ...
                def HasField(self, field_name: typing.Literal["actionType", b"actionType", "messageID", b"messageID", "supplementalKey", b"supplementalKey"]) -> builtins.bool: ...
                def ClearField(self, field_name: typing.Literal["actionType", b"actionType", "messageID", b"messageID", "supplementalKey", b"supplementalKey"]) -> None: ...

            @typing.final
            class ICDCParticipantDevices(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                @typing.final
                class ICDCIdentityListDescription(google.protobuf.message.Message):
                    DESCRIPTOR: google.protobuf.descriptor.Descriptor

                    SEQ_FIELD_NUMBER: builtins.int
                    SIGNINGDEVICE_FIELD_NUMBER: builtins.int
                    UNKNOWNDEVICES_FIELD_NUMBER: builtins.int
                    UNKNOWNDEVICEIDS_FIELD_NUMBER: builtins.int
                    seq: builtins.int
                    signingDevice: builtins.bytes
                    @property
                    def unknownDevices(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.bytes]: ...
                    @property
                    def unknownDeviceIDs(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
                    def __init__(
                        self,
                        *,
                        seq: builtins.int | None = ...,
                        signingDevice: builtins.bytes | None = ...,
                        unknownDevices: collections.abc.Iterable[builtins.bytes] | None = ...,
                        unknownDeviceIDs: collections.abc.Iterable[builtins.int] | None = ...,
                    ) -> None: ...
                    def HasField(self, field_name: typing.Literal["seq", b"seq", "signingDevice", b"signingDevice"]) -> builtins.bool: ...
                    def ClearField(self, field_name: typing.Literal["seq", b"seq", "signingDevice", b"signingDevice", "unknownDeviceIDs", b"unknownDeviceIDs", "unknownDevices", b"unknownDevices"]) -> None: ...

                SENDERIDENTITY_FIELD_NUMBER: builtins.int
                RECIPIENTIDENTITIES_FIELD_NUMBER: builtins.int
                RECIPIENTUSERJIDS_FIELD_NUMBER: builtins.int
                @property
                def senderIdentity(self) -> global___MessageTransport.Protocol.Ancillary.ICDCParticipantDevices.ICDCIdentityListDescription: ...
                @property
                def recipientIdentities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MessageTransport.Protocol.Ancillary.ICDCParticipantDevices.ICDCIdentityListDescription]: ...
                @property
                def recipientUserJIDs(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
                def __init__(
                    self,
                    *,
                    senderIdentity: global___MessageTransport.Protocol.Ancillary.ICDCParticipantDevices.ICDCIdentityListDescription | None = ...,
                    recipientIdentities: collections.abc.Iterable[global___MessageTransport.Protocol.Ancillary.ICDCParticipantDevices.ICDCIdentityListDescription] | None = ...,
                    recipientUserJIDs: collections.abc.Iterable[builtins.str] | None = ...,
                ) -> None: ...
                def HasField(self, field_name: typing.Literal["senderIdentity", b"senderIdentity"]) -> builtins.bool: ...
                def ClearField(self, field_name: typing.Literal["recipientIdentities", b"recipientIdentities", "recipientUserJIDs", b"recipientUserJIDs", "senderIdentity", b"senderIdentity"]) -> None: ...

            @typing.final
            class SenderKeyDistributionMessage(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                GROUPID_FIELD_NUMBER: builtins.int
                AXOLOTLSENDERKEYDISTRIBUTIONMESSAGE_FIELD_NUMBER: builtins.int
                groupID: builtins.str
                axolotlSenderKeyDistributionMessage: builtins.bytes
                def __init__(
                    self,
                    *,
                    groupID: builtins.str | None = ...,
                    axolotlSenderKeyDistributionMessage: builtins.bytes | None = ...,
                ) -> None: ...
                def HasField(self, field_name: typing.Literal["axolotlSenderKeyDistributionMessage", b"axolotlSenderKeyDistributionMessage", "groupID", b"groupID"]) -> builtins.bool: ...
                def ClearField(self, field_name: typing.Literal["axolotlSenderKeyDistributionMessage", b"axolotlSenderKeyDistributionMessage", "groupID", b"groupID"]) -> None: ...

            SKDM_FIELD_NUMBER: builtins.int
            DEVICELISTMETADATA_FIELD_NUMBER: builtins.int
            ICDC_FIELD_NUMBER: builtins.int
            BACKUPDIRECTIVE_FIELD_NUMBER: builtins.int
            @property
            def skdm(self) -> global___MessageTransport.Protocol.Ancillary.SenderKeyDistributionMessage: ...
            @property
            def deviceListMetadata(self) -> global___DeviceListMetadata: ...
            @property
            def icdc(self) -> global___MessageTransport.Protocol.Ancillary.ICDCParticipantDevices: ...
            @property
            def backupDirective(self) -> global___MessageTransport.Protocol.Ancillary.BackupDirective: ...
            def __init__(
                self,
                *,
                skdm: global___MessageTransport.Protocol.Ancillary.SenderKeyDistributionMessage | None = ...,
                deviceListMetadata: global___DeviceListMetadata | None = ...,
                icdc: global___MessageTransport.Protocol.Ancillary.ICDCParticipantDevices | None = ...,
                backupDirective: global___MessageTransport.Protocol.Ancillary.BackupDirective | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["backupDirective", b"backupDirective", "deviceListMetadata", b"deviceListMetadata", "icdc", b"icdc", "skdm", b"skdm"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["backupDirective", b"backupDirective", "deviceListMetadata", b"deviceListMetadata", "icdc", b"icdc", "skdm", b"skdm"]) -> None: ...

        @typing.final
        class Integral(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            @typing.final
            class DeviceSentMessage(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                DESTINATIONJID_FIELD_NUMBER: builtins.int
                PHASH_FIELD_NUMBER: builtins.int
                destinationJID: builtins.str
                phash: builtins.str
                def __init__(
                    self,
                    *,
                    destinationJID: builtins.str | None = ...,
                    phash: builtins.str | None = ...,
                ) -> None: ...
                def HasField(self, field_name: typing.Literal["destinationJID", b"destinationJID", "phash", b"phash"]) -> builtins.bool: ...
                def ClearField(self, field_name: typing.Literal["destinationJID", b"destinationJID", "phash", b"phash"]) -> None: ...

            PADDING_FIELD_NUMBER: builtins.int
            DSM_FIELD_NUMBER: builtins.int
            padding: builtins.bytes
            @property
            def DSM(self) -> global___MessageTransport.Protocol.Integral.DeviceSentMessage: ...
            def __init__(
                self,
                *,
                padding: builtins.bytes | None = ...,
                DSM: global___MessageTransport.Protocol.Integral.DeviceSentMessage | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["DSM", b"DSM", "padding", b"padding"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["DSM", b"DSM", "padding", b"padding"]) -> None: ...

        INTEGRAL_FIELD_NUMBER: builtins.int
        ANCILLARY_FIELD_NUMBER: builtins.int
        @property
        def integral(self) -> global___MessageTransport.Protocol.Integral: ...
        @property
        def ancillary(self) -> global___MessageTransport.Protocol.Ancillary: ...
        def __init__(
            self,
            *,
            integral: global___MessageTransport.Protocol.Integral | None = ...,
            ancillary: global___MessageTransport.Protocol.Ancillary | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["ancillary", b"ancillary", "integral", b"integral"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["ancillary", b"ancillary", "integral", b"integral"]) -> None: ...

    PAYLOAD_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    @property
    def payload(self) -> global___MessageTransport.Payload: ...
    @property
    def protocol(self) -> global___MessageTransport.Protocol: ...
    def __init__(
        self,
        *,
        payload: global___MessageTransport.Payload | None = ...,
        protocol: global___MessageTransport.Protocol | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["payload", b"payload", "protocol", b"protocol"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["payload", b"payload", "protocol", b"protocol"]) -> None: ...

global___MessageTransport = MessageTransport

@typing.final
class DeviceListMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SENDERKEYHASH_FIELD_NUMBER: builtins.int
    SENDERTIMESTAMP_FIELD_NUMBER: builtins.int
    RECIPIENTKEYHASH_FIELD_NUMBER: builtins.int
    RECIPIENTTIMESTAMP_FIELD_NUMBER: builtins.int
    senderKeyHash: builtins.bytes
    senderTimestamp: builtins.int
    recipientKeyHash: builtins.bytes
    recipientTimestamp: builtins.int
    def __init__(
        self,
        *,
        senderKeyHash: builtins.bytes | None = ...,
        senderTimestamp: builtins.int | None = ...,
        recipientKeyHash: builtins.bytes | None = ...,
        recipientTimestamp: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["recipientKeyHash", b"recipientKeyHash", "recipientTimestamp", b"recipientTimestamp", "senderKeyHash", b"senderKeyHash", "senderTimestamp", b"senderTimestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["recipientKeyHash", b"recipientKeyHash", "recipientTimestamp", b"recipientTimestamp", "senderKeyHash", b"senderKeyHash", "senderTimestamp", b"senderTimestamp"]) -> None: ...

global___DeviceListMetadata = DeviceListMetadata



from ..proto.waE2E.WAWebProtobufsE2E_pb2 import (
    Message,
    ImageMessage,
    DocumentMessage,
    ExtendedTextMessage,
    VideoMessage,
    PollUpdateMessage,
)
from ..proto import Neonize_pb2 as neonize_proto
from ..types import MediaMessageType, TextMessageType


def get_message_type(message: Message) -> MediaMessageType | TextMessageType:
    """
    Determines the type of message.

    :param message: The message object.
    :type message: Message
    :raises IndexError: If the message type cannot be determined.
    :return: The type of the message.
    :rtype: MediaMessageType | TextMessageType
    """
    for field_name, v in message.ListFields():
        if field_name.name.endswith("Message"):
            return v
        elif field_name.name == "conversation":
            return v
    raise IndexError()


def extract_text(message: Message):
    """
    Extracts text content from a message.

    :param message: The message object.
    :type message: Message
    :return: The extracted text content.
    :rtype: str
    """
    if message.imageMessage.ListFields():
        imageMessage: ImageMessage = message.imageMessage
        return imageMessage.caption
    elif message.extendedTextMessage.ListFields():
        extendedTextMessage: ExtendedTextMessage = message.extendedTextMessage
        return extendedTextMessage.text
    elif message.videoMessage.ListFields():
        videoMessage: VideoMessage = message.videoMessage
        return videoMessage.caption
    elif message.documentMessage.ListFields():
        documentMessage: DocumentMessage = message.documentMessage
        return documentMessage.caption
    elif message.conversation:
        return message.conversation
    return ""


def get_poll_update_message(message: neonize_proto.Message) -> PollUpdateMessage | None:
    """
    Extracts pollUpdateMessage from event Message
    :param message: The message object.
    :type message: neonize_proto.Message
    :return: The extracted poll update message.
    :rtype: PollUpdateMessage
    """
    msg = message.Message
    if msg.pollUpdateMessage.ListFields():
        pollUpdateMessage: PollUpdateMessage = msg.pollUpdateMessage
        return pollUpdateMessage



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waAdv/WAAdv.proto
# Protobuf Python Version: 5.28.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    2,
    '',
    'waAdv/WAAdv.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11waAdv/WAAdv.proto\x12\x05WAAdv\"\x92\x01\n\x0f\x41\x44VKeyIndexList\x12\r\n\x05rawID\x18\x01 \x01(\r\x12\x11\n\ttimestamp\x18\x02 \x01(\x04\x12\x14\n\x0c\x63urrentIndex\x18\x03 \x01(\r\x12\x18\n\x0cvalidIndexes\x18\x04 \x03(\rB\x02\x10\x01\x12-\n\x0b\x61\x63\x63ountType\x18\x05 \x01(\x0e\x32\x18.WAAdv.ADVEncryptionType\"_\n\x15\x41\x44VSignedKeyIndexList\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\x0c\x12\x18\n\x10\x61\x63\x63ountSignature\x18\x02 \x01(\x0c\x12\x1b\n\x13\x61\x63\x63ountSignatureKey\x18\x03 \x01(\x0c\"\xa4\x01\n\x11\x41\x44VDeviceIdentity\x12\r\n\x05rawID\x18\x01 \x01(\r\x12\x11\n\ttimestamp\x18\x02 \x01(\x04\x12\x10\n\x08keyIndex\x18\x03 \x01(\r\x12-\n\x0b\x61\x63\x63ountType\x18\x04 \x01(\x0e\x32\x18.WAAdv.ADVEncryptionType\x12,\n\ndeviceType\x18\x05 \x01(\x0e\x32\x18.WAAdv.ADVEncryptionType\"z\n\x17\x41\x44VSignedDeviceIdentity\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\x0c\x12\x1b\n\x13\x61\x63\x63ountSignatureKey\x18\x02 \x01(\x0c\x12\x18\n\x10\x61\x63\x63ountSignature\x18\x03 \x01(\x0c\x12\x17\n\x0f\x64\x65viceSignature\x18\x04 \x01(\x0c\"k\n\x1b\x41\x44VSignedDeviceIdentityHMAC\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\x0c\x12\x0c\n\x04HMAC\x18\x02 \x01(\x0c\x12-\n\x0b\x61\x63\x63ountType\x18\x03 \x01(\x0e\x32\x18.WAAdv.ADVEncryptionType*)\n\x11\x41\x44VEncryptionType\x12\x08\n\x04\x45\x32\x45\x45\x10\x00\x12\n\n\x06HOSTED\x10\x01\x42!Z\x1fgo.mau.fi/whatsmeow/proto/waAdv')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waAdv.WAAdv_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\037go.mau.fi/whatsmeow/proto/waAdv'
  _globals['_ADVKEYINDEXLIST'].fields_by_name['validIndexes']._loaded_options = None
  _globals['_ADVKEYINDEXLIST'].fields_by_name['validIndexes']._serialized_options = b'\020\001'
  _globals['_ADVENCRYPTIONTYPE']._serialized_start=674
  _globals['_ADVENCRYPTIONTYPE']._serialized_end=715
  _globals['_ADVKEYINDEXLIST']._serialized_start=29
  _globals['_ADVKEYINDEXLIST']._serialized_end=175
  _globals['_ADVSIGNEDKEYINDEXLIST']._serialized_start=177
  _globals['_ADVSIGNEDKEYINDEXLIST']._serialized_end=272
  _globals['_ADVDEVICEIDENTITY']._serialized_start=275
  _globals['_ADVDEVICEIDENTITY']._serialized_end=439
  _globals['_ADVSIGNEDDEVICEIDENTITY']._serialized_start=441
  _globals['_ADVSIGNEDDEVICEIDENTITY']._serialized_end=563
  _globals['_ADVSIGNEDDEVICEIDENTITYHMAC']._serialized_start=565
  _globals['_ADVSIGNEDDEVICEIDENTITYHMAC']._serialized_end=672
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waMediaEntryData/WAMediaEntryData.proto
# Protobuf Python Version: 5.28.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    2,
    '',
    'waMediaEntryData/WAMediaEntryData.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'waMediaEntryData/WAMediaEntryData.proto\x12\x10WAMediaEntryData\"\xc9\x05\n\nMediaEntry\x12\x12\n\nfileSHA256\x18\x01 \x01(\x0c\x12\x10\n\x08mediaKey\x18\x02 \x01(\x0c\x12\x15\n\rfileEncSHA256\x18\x03 \x01(\x0c\x12\x12\n\ndirectPath\x18\x04 \x01(\t\x12\x19\n\x11mediaKeyTimestamp\x18\x05 \x01(\x03\x12\x17\n\x0fserverMediaType\x18\x06 \x01(\t\x12\x13\n\x0buploadToken\x18\x07 \x01(\x0c\x12\x1a\n\x12validatedTimestamp\x18\x08 \x01(\x0c\x12\x0f\n\x07sidecar\x18\t \x01(\x0c\x12\x10\n\x08objectID\x18\n \x01(\t\x12\x0c\n\x04\x46\x42ID\x18\x0b \x01(\t\x12Q\n\x15\x64ownloadableThumbnail\x18\x0c \x01(\x0b\x32\x32.WAMediaEntryData.MediaEntry.DownloadableThumbnail\x12\x0e\n\x06handle\x18\r \x01(\t\x12\x10\n\x08\x66ilename\x18\x0e \x01(\t\x12S\n\x16progressiveJPEGDetails\x18\x0f \x01(\x0b\x32\x33.WAMediaEntryData.MediaEntry.ProgressiveJpegDetails\x12\x0c\n\x04size\x18\x10 \x01(\x03\x12$\n\x1clastDownloadAttemptTimestamp\x18\x11 \x01(\x03\x1a>\n\x16ProgressiveJpegDetails\x12\x13\n\x0bscanLengths\x18\x01 \x03(\r\x12\x0f\n\x07sidecar\x18\x02 \x01(\x0c\x1a\x95\x01\n\x15\x44ownloadableThumbnail\x12\x12\n\nfileSHA256\x18\x01 \x01(\x0c\x12\x15\n\rfileEncSHA256\x18\x02 \x01(\x0c\x12\x12\n\ndirectPath\x18\x03 \x01(\t\x12\x10\n\x08mediaKey\x18\x04 \x01(\x0c\x12\x19\n\x11mediaKeyTimestamp\x18\x05 \x01(\x03\x12\x10\n\x08objectID\x18\x06 \x01(\tB,Z*go.mau.fi/whatsmeow/proto/waMediaEntryData')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waMediaEntryData.WAMediaEntryData_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z*go.mau.fi/whatsmeow/proto/waMediaEntryData'
  _globals['_MEDIAENTRY']._serialized_start=62
  _globals['_MEDIAENTRY']._serialized_end=775
  _globals['_MEDIAENTRY_PROGRESSIVEJPEGDETAILS']._serialized_start=561
  _globals['_MEDIAENTRY_PROGRESSIVEJPEGDETAILS']._serialized_end=623
  _globals['_MEDIAENTRY_DOWNLOADABLETHUMBNAIL']._serialized_start=626
  _globals['_MEDIAENTRY_DOWNLOADABLETHUMBNAIL']._serialized_end=775
# @@protoc_insertion_point(module_scope)
